macro_rules! debug_warn {
($($arg:tt)+) => { ... };
}Expand description
Log a warning in debug builds, or a debug message in release builds.
This is useful for logging messages that should be visible during development (to help catch issues), but shouldn’t spam the logs in release builds.
In debug builds, the message is prefixed with “DEBUG: “ and logged at WARN level. In release builds, the message is logged at DEBUG level without any prefix.
This macro never triggers panic-on-warn (RERUN_PANIC_ON_WARN or PanicOnWarnScope):
that is meant to catch user-facing warnings, and this macro is never a warning
in release builds.