debug_warn

Macro debug_warn 

macro_rules! debug_warn {
    ($($arg:tt)+) => { ... };
}
Log a warning in debug builds, or a debug message in release builds.

This is useful for logging messages that should be visible during development (to help catch issues), but shouldn’t spam the logs in release builds.

In debug builds, the message is prefixed with “DEBUG: “ and logged at WARN level. In release builds, the message is logged at DEBUG level without any prefix.